summaryrefslogtreecommitdiffstats
path: root/chrome/installer/gcapi/gcapi.h
diff options
context:
space:
mode:
authorrobertshield@chromium.org <robertshield@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-12-05 20:56:10 +0000
committerrobertshield@chromium.org <robertshield@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-12-05 20:56:10 +0000
commit0b5a90621e6bba8549c50cd99fd44ed07e8e30f8 (patch)
treee939c413e2074f29abf1542aec9e19d5cd3c3cae /chrome/installer/gcapi/gcapi.h
parent52b03a6600169de2382951882f25653706332ad9 (diff)
downloadchromium_src-0b5a90621e6bba8549c50cd99fd44ed07e8e30f8.zip
chromium_src-0b5a90621e6bba8549c50cd99fd44ed07e8e30f8.tar.gz
chromium_src-0b5a90621e6bba8549c50cd99fd44ed07e8e30f8.tar.bz2
Fix up GCAPI's LaunchGoogleChrome() method to use the current way of finding the path to chrome.exe.
Fix LaunchGoogleChromeWithDimensions such that it looks for the correctly named window for current Chromes. Add an in_background parameter to LaunchGoogleChromeWithDimensions() that will place the launched Chrome window behind all other windows. Remove usage of ATL (was pulled in only for CComPtr). BUG=NONE TEST=NONE Review URL: http://codereview.chromium.org/8776038 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@113016 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/installer/gcapi/gcapi.h')
-rw-r--r--chrome/installer/gcapi/gcapi.h17
1 files changed, 10 insertions, 7 deletions
diff --git a/chrome/installer/gcapi/gcapi.h b/chrome/installer/gcapi/gcapi.h
index b61e315..a9fd040 100644
--- a/chrome/installer/gcapi/gcapi.h
+++ b/chrome/installer/gcapi/gcapi.h
@@ -27,20 +27,23 @@ extern "C" {
BOOL __stdcall GoogleChromeCompatibilityCheck(BOOL set_flag, DWORD* reasons);
// This function launches Google Chrome after a successful install. Make
-// sure COM library is NOT initalized before you call this function (so if
+// sure COM library is NOT initialized before you call this function (so if
// you called CoInitialize, call CoUninitialize before calling this function).
BOOL __stdcall LaunchGoogleChrome();
// This function launches Google Chrome after a successful install at the
// given x,y coordinates with size height,length. Make
// sure COM library is NOT initalized before you call this function (so if
// you called CoInitialize, call CoUninitialize before calling this function).
// This call is synchronous, meaning it waits for Chrome to launch and appear
// to resize it before returning.
BOOL __stdcall LaunchGoogleChromeWithDimensions(int x,
- int y,
- int width,
- int height);
+ int y,
+ int width,
+ int height,
+ bool in_background);
// This function returns the number of days since Google Chrome was last run by
// the current user. If both user-level and machine-wide installations are
@@ -27,20 +27,23 @@ extern "C" {
BOOL __stdcall LaunchGoogleChrome();
// This function launches Google Chrome after a successful install at the
-// given x,y coordinates with size height,length. Make
-// sure COM library is NOT initalized before you call this function (so if
-// you called CoInitialize, call CoUninitialize before calling this function).
+// given x,y coordinates with size height,length. Set in_background to true
+// to move Google Chrome behind all other windows or false to have it appear
+// at the default z-order. Make sure that COM is NOT initialized before you call
+// this function (so if you called CoInitialize, call CoUninitialize before
+// calling this function).
// This call is synchronous, meaning it waits for Chrome to launch and appear
// to resize it before returning.